AndroidBuildVersion class

Version values of the current Android operating system build derived from android.os.Build.VERSION.

See: https://developer.android.com/reference/android/os/Build.VERSION.html

Properties

baseOS → String?
The base OS build the product is based on.
final
codename → String?
The current development codename, or the string "REL" if this is a release build.
final
hashCode → int
The hash code for this object.
no setterinherited
incremental → String?
The internal value used by the underlying source control to represent this build.
final
previewSdkInt → int?
The developer preview revision of a prerelease SDK.
final
release → String?
The user-visible version string.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sdkInt → int?
The user-visible SDK version of the framework.
final
securityPatch → String?
The user-visible security patch level.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Serializes AndroidBuildVersion to map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited