AndroidDeviceInfo class

Information derived from android.os.Build.

See: https://developer.android.com/reference/android/os/Build.html

Implemented types

Constructors

AndroidDeviceInfo({required AndroidBuildVersion version, String? board, String? bootloader, String? brand, String? device, String? display, String? fingerprint, String? hardware, String? host, String? id, String? manufacturer, String? model, String? product, required List<String?> supported32BitAbis, required List<String?> supported64BitAbis, required List<String?> supportedAbis, String? tags, String? type, bool? isPhysicalDevice, required List<String?> systemFeatures})
Android device Info class.

Properties

board → String?
The name of the underlying board, like "goldfish".
final
bootloader → String?
The system bootloader version number.
final
brand → String?
The consumer-visible brand with which the product/hardware will be associated, if any.
final
device → String?
The name of the industrial design.
final
display → String?
A build ID string meant for displaying to the user.
final
fingerprint → String?
A string that uniquely identifies this build.
final
hardware → String?
The name of the hardware (from the kernel command line or /proc).
final
hashCode → int
The hash code for this object.
no setterinherited
host → String?
Hostname.
final
id → String?
Either a changelist number, or a label like "M4-rc20".
final
isPhysicalDevice → bool?
false if the application is running in an emulator, true otherwise.
final
manufacturer → String?
The manufacturer of the product/hardware.
final
model → String?
The end-user-visible name for the end product.
final
product → String?
The name of the overall product.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supported32BitAbis → List<String?>
An ordered list of 32 bit ABIs supported by this device.
final
supported64BitAbis → List<String?>
An ordered list of 64 bit ABIs supported by this device.
final
supportedAbis → List<String?>
An ordered list of ABIs supported by this device.
final
systemFeatures → List<String?>
Describes what features are available on the current device.
final
tags → String?
Comma-separated tags describing the build, like "unsigned,debug".
final
type → String?
The type of build, like "user" or "eng".
final
version → AndroidBuildVersion
Android operating system version values derived from android.os.Build.VERSION.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Serializes AndroidDeviceInfo to map.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic> map) → AndroidDeviceInfo
Deserializes from the message received from _kChannel.